abacusai.graph_dashboard — AbacusAI documentation

# `abacusai.graph_dashboard`

## Module Contents

### Classes

`GraphDashboard` | A Graph Dashboard

class abacusai.graph_dashboard.GraphDashboard(client, name=None, graphDashboardId=None, createdAt=None, projectId=None, pythonFunctionIds=None, pythonFunctionNames=None, projectName=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  A Graph Dashboard

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - name (str) – The user-friendly name for the plot dashboard

    - graphDashboardId (str) – The unique identifier of the graph dashboard.

    - createdAt (str) – Date and time at which the graph dashboard was created.

    - projectId (str) – The project this model belongs to.

    - pythonFunctionIds (list<unique string identifier>)) – List of python graph ids included in the dashboard

    - pythonFunctionNames (list<string>) – List of names of each of the python functions

    - projectName (str) – The name the plot dashboard belongs to

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict

  refresh()

    Calls describe and refreshes the current object’s fields

    Returns:

      The current object

    Return type:

      GraphDashboard

  describe()

    Describes a given graph dashboard.

    Parameters:

      graph_dashboard_id (str) – The graph dashboard id

    Returns:

      An object describing the graph dashboard

    Return type:

      GraphDashboard

  delete()

    Deletes a graph dashboard

    Parameters:

      graph_dashboard_id (str) – The graph dashboard id to delete

  update(name=None, python_function_ids=None, variable_mappings=None)

    Updates a graph dashboard

    Parameters:

      - name (str) – The name of the dashboard

      - python_function_ids (list) – The list of python function ids to use in the graph dashboard

      - variable_mappings (dict) –

    Returns:

      An object describing the graph dashboard

    Return type:

      GraphDashboard